Token

Enum Token 

#[non_exhaustive]
pub enum Token {
Show 25 variants Ident(String), Function(String), AtKeyword(String), Hash { value: String, type_flag: HashType, }, String(String), BadString, Url(String), BadUrl, Delim(char), Number { value: f64, type_flag: NumericType, }, Percentage { value: f64, }, Dimension { value: f64, type_flag: NumericType, unit: String, }, Whitespace, Cdo, Cdc, Colon, Semicolon, Comma, OpenSquare, CloseSquare, OpenParen, CloseParen, OpenCurly, CloseCurly, Eof,
}
A single CSS token, per spec 4.3.1 (“Consume a token”) and the token types defined at the start of 4.3.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Ident(String)

An identifier, e.g. screen.



Function(String)

An identifier immediately followed by (, e.g. calc(. The ( itself is consumed but not part of the stored string.



AtKeyword(String)

@ followed by an ident sequence, e.g. @media.



Hash

# followed by an ident-code-point/escape sequence, e.g. #foo.

Fields

value: String

The value after #.

type_flag: HashType

Whether the value would itself be a valid ID selector.



String(String)

A quoted string, e.g. "screen".



BadString

A string that was not terminated correctly (e.g. an unescaped newline before the closing quote).



Url(String)

A url(...) token with an unquoted value.



BadUrl

A url(...) construct that could not be tokenized as a valid URL token (e.g. an unescaped space in the unquoted value).



Delim(char)

A single code point that didn’t start any other token, e.g. ^.



Number

A numeric literal with no unit or % suffix, e.g. 42.

Fields

value: f64

The parsed numeric value.

type_flag: NumericType

Whether the literal had a fractional part/exponent.



Percentage

A numeric literal followed by %, e.g. 50%.

Fields

value: f64

The parsed numeric value (before the %).



Dimension

A numeric literal followed by a unit, e.g. 10px.

Fields

value: f64

The parsed numeric value (before the unit).

type_flag: NumericType

Whether the literal had a fractional part/exponent.

unit: String

The unit identifier, e.g. px.



Whitespace

One or more consecutive whitespace code points.



Cdo

<!--



Cdc

-->



Colon

:



Semicolon

;



Comma

,



OpenSquare

[



CloseSquare

]



OpenParen

(



CloseParen

)



OpenCurly

{



CloseCurly

}



Eof

The end of the input stream. Always the last token produced by Tokenizer, never followed by another token.