#[non_exhaustive]pub enum MediaModifier {
Not,
Only,
}Expand description
not | only, as used in the <media-type> branch of <media-query>.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Not
not: negates the whole <media-query>.
Only
only: present only to hide the query from legacy UAs that
don’t support media types other than the four originally
defined ones; has no effect on this crate’s parsing result.